@@ -380,8 +380,8 @@ func (qr *questionRepo) GetQuestionPage(ctx context.Context, page, pageSize int,
 		}
 		session.And("question.post_update_time > ?", time.Now().AddDate(0, 0, -90))
 		session.OrderBy("question.pin desc,question.post_update_time DESC, question.updated_at DESC")
-	case "frequent":
-		session.OrderBy("question.pin desc,question.view_count DESC")
+	case "hot":
+		session.OrderBy("question.pin desc,question.hot_score DESC")
 	case "score":
 		session.OrderBy("question.pin desc,question.vote_count DESC, question.view_count DESC")
 	case "unanswered":
