@@ -220,8 +220,8 @@ func (u *UserRegisterReq) Check() (errFields []*validator.FormErrorField, err er
 type UserModifyPasswordReq struct {
 	OldPass     string `validate:"omitempty,gte=8,lte=32" json:"old_pass"`
 	Pass        string `validate:"required,gte=8,lte=32" json:"pass"`
-	CaptchaID   string `validate:"omitempty,gt=0,lte=500" json:"captcha_id"`
-	CaptchaCode string `validate:"omitempty,gt=0,lte=500" json:"captcha_code"`
+	CaptchaID   string `json:"captcha_id"`
+	CaptchaCode string `json:"captcha_code"`
 	UserID      string `json:"-"`
 	AccessToken string `json:"-"`
 }
@@ -382,8 +382,8 @@ type UserChangeEmailVerifyReq struct {
 }
 
 type UserVerifyEmailSendReq struct {
-	CaptchaID   string `validate:"omitempty,gt=0,lte=500" json:"captcha_id"`
-	CaptchaCode string `validate:"omitempty,gt=0,lte=500" json:"captcha_code"`
+	CaptchaID   string `json:"captcha_id"`
+	CaptchaCode string `json:"captcha_code"`
 }
 
 // UserRankingResp user ranking response
@@ -412,3 +412,19 @@ type UserUnsubscribeNotificationReq struct {
 	Code    string `validate:"required,gt=0,lte=500" json:"code"`
 	Content string `json:"-"`
 }
+
+// GetUserStaffReq get user staff request
+type GetUserStaffReq struct {
+	Username string `validate:"omitempty,gt=0,lte=500" form:"username"`
+	PageSize int    `validate:"omitempty,min=1" form:"page_size"`
+}
+
+// GetUserStaffResp get user staff response
+type GetUserStaffResp struct {
+	// username
+	Username string `json:"username"`
+	// display name
+	DisplayName string `json:"display_name"`
+	// avatar
+	Avatar string `json:"avatar"`
+}
