@@ -102,6 +102,10 @@ func Register(p Base) {
 	if _, ok := p.(Embed); ok {
 		registerEmbed(p.(Embed))
 	}
+
+	if _, ok := p.(CDN); ok {
+		registerCDN(p.(CDN))
+	}
 }
 
 type Stack[T Base] struct {
@@ -159,9 +163,14 @@ func (m *statusManager) Enable(name string, enabled bool) {
 		return
 	}
 	m.status[name] = enabled
+
 	for _, slugName := range coordinatedCaptchaPlugins(name) {
 		m.status[slugName] = false
 	}
+
+	for _, slugName := range coordinatedCDNPlugins(name) {
+		m.status[slugName] = false
+	}
 }
 
 func (m *statusManager) IsEnabled(name string) bool {
